# Permission to Relicense under MPLv2 or any other OSI approved license chosen by the current PyZMQ BDFL

This is a statement by LedgerX LLC. that grants permission to relicense its copyrights in the Python ZeroMQ bindings (pyzmq) under the Mozilla Public License v2 (MPLv2).

A portion of the commits made by the GitHub handle "amrali", with commit author "Amr Ali <amr@ledgerx.com>", are copyright of LedgerX LLC. This document hereby grants the pyzmq project team permission to relicense pyzmq, including all past, present, and future contributions of the author listed above.

Amr Ali
2017/09/11
